######################################################################
#
# Croatian Language text and icon macros 
#
######################################################################
#
# This is the main macro file for translation when creating an 
# interface in another language.
#
# Under the 'text macros' comments are text macros of the form:
# _macroname_ {macro value}
# Everything between the {} is the text to be translated. This text 
# may itself contain macros (i.e. characters other than space between
# underscore characters, e.g. _about:numdocs_ or _textpage_). These
# macro names occurring within text shouldn't be translated but should
# be left as they are. Underscores or curly brackets occurring 
# naturally within the text should be escaped with a leading backslash
# (i.e. '\_', '\{' or '\}).
#
# Under the 'icons' comments are macros concerned with displaying
# icons which themselves contain text.
# Above each macro (or group of macros) for an icon is a comment line
# that looks something like '## "HOME" ## top_nav_button ## chome ##'.
# The first field of the comment ("HOME" in this case) is the text
# that appears in the english version of the icon. This is the text
# that must be translated, nothing needs to be done to the macros 
# themselves. The other two fields of the comments are used by 
# automatic icon generating software which reads the newly translated
# file and generates appropriate icons.
#
# Comment lines (other than those described above) need not be 
# translated (i.e. any lines beginning with '#', like this line).
#
# The simplest way to translate this file is to save it as something
# else (e.g. french.dm) and work through translating all the text
# macro values and icon comments.
#
######################################################################


######################################################################
# Global (base) package
package Global
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textperiodicals_ [l=hr] {Serijske publikacije}
_textsource_ [l=hr] {izvor: }
_textdate_ [l=hr] {datum izdavanja: }
_textnumpages_ [l=hr] {broj stranica: }

_textsignin_ [l=hr] {prijavi se}

_textdefaultcontent_ [l=hr] {Tražena stranica nije pronađena. Molimo vas koristite funkciju 
"back" na vašem pregledniku ili funkciju "home" za povratak u Greenstone Digital Library.}

_textdefaulttitle_ [l=hr] {GSDL Pogreška}

_collectionextra_ [l=hr] {Ova zbirka sadrži _about:numdocs_ dokumen(a)ta. 
Zadnji put je bila ažurirana prije _about:builddate_ dana.}

# this is only used by the collector (where the above _collectionextra_
# macro will always be set to another value)
_collectorextra_ [l=hr] {
<p>Ova zbirka se sastoji od _numdocs_ _If_("_numdocs_" eq "1",dokumenta,dokumenta), sa ukupno _numbytes_.
<p><a href="_httppagex_(bsummary)">Klikni ovdje</a> za pristup sistemskim podacima o zbirci.}

_textimagecollection_ [l=hr] {}
_textimageabout_ [l=hr] {O zbirci}
_textimagehome_ [l=hr] {Naslovna stranica}
_textimagehelp_ [l=hr] {Pomoć}
_textimagepref_ [l=hr] {Postavke}
_textimagegreenstone_ [l=hr] {Greenstone Digital Library Softver}

_textimagesearch_ [l=hr] {Traži prema određenim pojmovima}
_textimageTitle_ [l=hr] {Pregledaj abecedni popis naslova}
_textimageList_ [l=hr] {Pregledaj popis dokumenata uključenih u zbirku}
_textimageCreator_ [l=hr] {Pregledaj abecedni popis autora}
_textimageSeries_ [l=hr] {Pregledaj prema izdanju}
_textimageDate_ [l=hr] {Pregledaj prema datumu}
_textimageSubject_ [l=hr] {Pregledaj prema područjima po kojima je razvrstana građa}
_textimageOrganization_ [l=hr] {Pregledaj prema nazivu organizacije}
_textimageHowto_ [l=hr] {Pregledaj "Kako da" kategoriju}
_textimageTopic_ [l=hr] {Pregledaj specijalni izbor tema}
_textimageBrowse_ [l=hr] {Pregledaj}
_textimagePeople_ [l=hr] {Pregledaj abecedni popis osoba}
_textimageLanguage_ [l=hr] {Pregledaj prema jeziku}
_textimageAcronym_ [l=hr] {Pregled akronima}
_textimagePhrase_ [l=hr] {Pregled fraza}
_textimageArtist_ [l=hr] {Pregled umjetnika}
_textimageSource_ [l=hr] {Pregledaj prema izvornom nazivu datoteke}
_textimageKeyword_ [l=hr] {Pregledaj prema ključnim riječima}

_texticontabsearchgreen_ [l=hr] {Traži}
_texticontabdategreen_ [l=hr] {Datumi}
_texticontabseriesgreen_ [l=hr] {Nizovi}
_texticontabauthorgreen_ [l=hr] {Autori A-Z}
_texticontabtitlegreen_ [l=hr] {Naslovi A-Z}
_texticontablistgreen_ [l=hr] {Ispis}
_texticontabsubjectgreen_ [l=hr] {Područja}
_texticontaborggreen_ [l=hr] {Organizacije}
_texticontabhowgreen_ [l=hr] {Kako da}
_texticontabtopicgreen_ [l=hr] {Teme}
_texticontabbrwsegreen_ [l=hr] {Pregled}
_texticontabbrowsgreen_ [l=hr] {Pregled}
_texticontabPeoplegreen_ [l=hr] {Ljudi A-Z}
_texticontabLanguagegreen_ [l=hr] {Jezik}
_texticontabAcronymgreen_ [l=hr] {Akronimi}
_texticontabPhrasegreen_ [l=hr] {Fraze}
_texticontabArtistgreen_ [l=hr] {Umjetnici}
_texticontabSourcegreen_ [l=hr] {Datoteke}
_texticontabKeywordgreen_ [l=hr] {Ključne riječi}

_texticontext_ [l=hr] {Pogledaj dokument}
_texticonclosedbook_ [l=hr] {otvori ovaj dokument i pogledaj njegov sadržaj}
_texticonnext_ [l=hr] {sljedeći odjeljak}
_texticonprev_ [l=hr] {prethodni odjeljak}

_texticonmidi_ [l=hr] {Pogledaj dokument u MIDI formatu}
_texticonmsword_ [l=hr] {Pogledaj dokument u Microsoft Word formatu}
_texticonpdf_ [l=hr] {Pogledaj dokument u PDF formatu}
_texticonps_ [l=hr] {Pogledaj dokument u PostScript formatu}
_texticonppt_ [l=hr] {Pogledaj dokument PowerPoint formatu}
_texticonrtf_ [l=hr] {Pogledaj dokument u RTF formatu}
_texticonxls_ [l=hr] {Pogledaj dokument u Microsoft Excel formatu}

_page_ [l=hr] {stranica }
_pages_ [l=hr] {stranice}
_of_ [l=hr] { od }
_vol_ [l=hr] {Br.}
_num_ [l=hr] {Br.}

_textmonth00_ [l=hr] {}
_textmonth01_ [l=hr] {Siječanj}
_textmonth02_ [l=hr] {Veljača}
_textmonth03_ [l=hr] {Ožujak}
_textmonth04_ [l=hr] {Travanj}
_textmonth05_ [l=hr] {Svibanj}
_textmonth06_ [l=hr] {Lipanj}
_textmonth07_ [l=hr] {Srpanj}
_textmonth08_ [l=hr] {Kolovoz}
_textmonth09_ [l=hr] {Rujan}
_textmonth10_ [l=hr] {Listopad}
_textmonth11_ [l=hr] {Studeni}
_textmonth12_ [l=hr] {Prosinac}

_Document_ [l=hr] {Dokument}
_Section_ [l=hr] {Odjeljak}
_Paragraph_ [l=hr] {Paragraf}

_magazines_ [l=hr] {Časopisi}

_nzdlpagefooter_ [l=hr] {<p>_iconblankbar_
<p><a href="http://www.nzdl.org">New Zealand Digital Library Project</a>
<br><a href="http://www.cs.waikato.ac.nz/cs">Department of Computer Science</a>, 
<a href="http://www.waikato.ac.nz">University of Waikato</a>, 
New Zealand}

#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "NASLOVNA" ## top_nav_button ## chome ##  ???
_httpiconchomeof_ [l=hr] {_httpimg_/hr/chomeof.gif}
_httpiconchomeon_ [l=hr] {_httpimg_/hr/chomeon.gif}

## "POMOĆ" ## top_nav_button ## chelp ##
_httpiconchelpof_ [l=hr] {_httpimg_/hr/chelpof.gif}
_httpiconchelpon_ [l=hr] {_httpimg_/hr/chelpon.gif}

## "POSTAVKE" ## top_nav_button ## cpref ##
_httpiconcprefof_ [l=hr] {_httpimg_/hr/cprefof.gif}
_httpiconcprefon_ [l=hr] {_httpimg_/hr/cprefon.gif}

## "POMOĆ" ## green_title ## h_help ##
_httpiconhhelp_ [l=hr] {_httpimg_/hr/h_help.gif}
_widthhhelp_ [l=hr] {200}
_heighthhelp_ [l=hr] {57}

## "autori a-z" ## nav_bar_button ## tauth ##
_httpicontauthgr_ [l=hr] {_httpimg_/hr/tauthgr.gif}
_httpicontauthof_ [l=hr] {_httpimg_/hr/tauthof.gif}
_httpicontauthon_ [l=hr] {_httpimg_/hr/tauthon.gif}
_widthtauthx_ [l=hr] {87}

## "nizovi" ## nav_bar_button ## tser ##
_httpicontsergr_ [l=hr] {_httpimg_/hr/tsergr.gif}
_httpicontserof_ [l=hr] {_httpimg_/hr/tserof.gif}
_httpicontseron_ [l=hr] {_httpimg_/hr/tseron.gif}
_widthtserx_ [l=hr] {87}

## "datumi" ## nav_bar_button ## tdate ##
_httpicontdategr_ [l=hr] {_httpimg_/hr/tdategr.gif}
_httpicontdateof_ [l=hr] {_httpimg_/hr/tdateof.gif}
_httpicontdateon_ [l=hr] {_httpimg_/hr/tdateon.gif}
_widthtdatex_ [l=hr] {87}

## "područja" ## nav_bar_button ## tsubj ##
_httpicontsubjgr_ [l=hr] {_httpimg_/hr/tsubjgr.gif}
_httpicontsubjon_ [l=hr] {_httpimg_/hr/tsubjon.gif}
_httpicontsubjof_ [l=hr] {_httpimg_/hr/tsubjof.gif}
_widthtsubjx_ [l=hr] {0}

## "organizacije" ## nav_bar_button ## torg ##
_httpicontorggr_ [l=hr] {_httpimg_/hr/torggr.gif}
_httpicontorgon_ [l=hr] {_httpimg_/hr/torgon.gif}
_httpicontorgof_ [l=hr] {_httpimg_/hr/torgof.gif}
_widthtorgx_ [l=hr] {102}

## "kako da" ## nav_bar_button ## thow ##
_httpiconthowgr_ [l=hr] {_httpimg_/hr/thowgr.gif}
_httpiconthowon_ [l=hr] {_httpimg_/hr/thowon.gif}
_httpiconthowof_ [l=hr] {_httpimg_/hr/thowof.gif}
_widththowx_ [l=hr] {87}

## "teme" ## nav_bar_button ## ttopic ##
_httpiconttopicgr_ [l=hr] {_httpimg_/hr/ttopicgr.gif}
_httpiconttopicon_ [l=hr] {_httpimg_/hr/ttopicon.gif}
_httpiconttopicof_ [l=hr] {_httpimg_/hr/ttopicof.gif}
_widthttopicx_ [l=hr] {87}

## "pregled" ## nav_bar_button ## tbrwse ##
_httpicontbrwsegr_ [l=hr] {_httpimg_/hr/tbrwsegr.gif}
_httpicontbrwseon_ [l=hr] {_httpimg_/hr/tbrwseon.gif}
_httpicontbrwseof_ [l=hr] {_httpimg_/hr/tbrwseof.gif}
_widthtbrwsex_ [l=hr] {87}

## "traži" ## nav_bar_button ## tsrch ##
_httpicontsrchgr_ [l=hr] {_httpimg_/hr/tsrchgr.gif}
_httpicontsrchof_ [l=hr] {_httpimg_/hr/tsrchof.gif}
_httpicontsrchon_ [l=hr] {_httpimg_/hr/tsrchon.gif}
_widthtsrchx_ [l=hr] {87}

## "naslovi a-z" ## nav_bar_button ## ttitl ##
_httpiconttitlgr_ [l=hr] {_httpimg_/hr/ttitlgr.gif}
_httpiconttitlof_ [l=hr] {_httpimg_/hr/ttitlof.gif}
_httpiconttitlon_ [l=hr] {_httpimg_/hr/ttitlon.gif}
_widthttitlx_ [l=hr] {90}

## "osobe" ## nav_bar_button ## tpeop ##
_httpicontpeopgr_ [l=hr] {_httpimg_/hr/tpeopgr.gif}
_httpicontpeopof_ [l=hr] {_httpimg_/hr/tpeopof.gif}
_httpicontpeopon_ [l=hr] {_httpimg_/hr/tpeopon.gif}
_widthtpeopx_ [l=hr] {87}

## "jezici" ## nav_bar_button ## tlang ##
_httpicontlanggr_ [l=hr] {_httpimg_/hr/tlanggr.gif}
_httpicontlangon_ [l=hr] {_httpimg_/hr/tlangon.gif}
_httpicontlangof_ [l=hr] {_httpimg_/hr/tlangof.gif}
_widthtlangx_ [l=hr] {87}

## "akronimi" ## nav_bar_button ## tacro ##
_httpicontacrogr_ [l=hr] {_httpimg_/hr/tacrogr.gif}
_httpicontacroof_ [l=hr] {_httpimg_/hr/tacroof.gif}
_httpicontacroon_ [l=hr] {_httpimg_/hr/tacroon.gif}
_widthtacrox_ [l=hr] {87}

## "fraze" ## nav_bar_button ## tphrse ##
_httpicontphrsegr_ [l=hr] {_httpimg_/hr/tphrsegr.gif}
_httpicontphrseof_ [l=hr] {_httpimg_/hr/tphrseof.gif}
_httpicontphrseon_ [l=hr] {_httpimg_/hr/tphrseon.gif}
_widthtphrsex_ [l=hr] {87}

## "umjetnici" ## nav_bar_button ## tartst ##
_httpicontartstgr_ [l=hr] {_httpimg_/hr/tartstgr.gif}
_httpicontartstof_ [l=hr] {_httpimg_/hr/tartstof.gif}
_httpicontartston_ [l=hr] {_httpimg_/hr/tartston.gif}
_widthtartstx_ [l=hr] {87}

## "nazivi datoteka" ## nav_bar_button ## tsrc ##
_httpicontsrcgr_ [l=hr] {_httpimg_/hr/tsrcgr.gif}
_httpicontsrcof_ [l=hr] {_httpimg_/hr/tsrcof.gif}
_httpicontsrcon_ [l=hr] {_httpimg_/hr/tsrcon.gif}
_widthtsrcx_ [l=hr] {130}

## "ključne riječi" ## nav_bar_button ## tkw ##
_httpicontkwgr_ [l=hr] {_httpimg_/hr/tkwgr.gif}
_httpicontkwof_ [l=hr] {_httpimg_/hr/tkwof.gif}
_httpicontkwon_ [l=hr] {_httpimg_/hr/tkwon.gif}
_widthtkwx_ [l=hr] {0}


######################################################################
# 'about' page
package about
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textabcol_ [l=hr] {O zbirci}

_textsubcols1_ [l=hr] {<p>Cijela zbirka sadrži _1_ podzbirk(i)e. 
Trenutno su dostupne: 
<blockquote>}

_textsubcols2_ [l=hr] {</blockquote>
Možeš provjeriti (i promijeniti) podzbirku koju trenutno koristiš na stranici Postavke.}


#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "o zbirci" ## green_title ## h_about ##
_httpiconhabout_ [l=hr] {_httpimg_/hr/h_about.gif}
_widthhabout_ [l=hr] {200}
_heighthabout_ [l=hr] {57}



######################################################################
# document package
package document
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_texticonhtitle_ [l=hr] {Naslovi A-Z}
_texticonhauth_ [l=hr] {Autori A-Z}
_texticonhsubj_ [l=hr] {Područja}
_texticonhser_ [l=hr] {Časopisi}
_texticonhdate_ [l=hr] {Datumi}
_texticonhhow_ [l=hr] {Kako da}
_texticonhorg_ [l=hr] {Organizacije}
_texticonhbrwse_ [l=hr] {Pregled}
_texticonhbrows_ [l=hr] {Pregled}
_texticonhpeople_ [l=hr] {Osobe A-Z}
_texticonhlanguage_ [l=hr] {Jezici}
_texticonhacronym_ [l=hr] {Akronimi}
_texticonhphrases_ [l=hr] {Fraze}
_texticonhartist_ [l=hr] {Umjetnici}
_texticonhsrc_ [l=hr] {Datoteke}
_texticonhkw_ [l=hr] {Ključne riječi}

_texticonopenbookshelf_ [l=hr] {zatvori ovaj odjeljak zbirke}
_texticonclosedbookshelf_ [l=hr] {otvori ovaj odjeljak zbirke i pogledaj sadržaj}
_texticonopenbook_ [l=hr] {zatvori dokument}
_texticonclosedfolder_ [l=hr] {otvori ovu mapu i pogledaj sadržaj}
_texticonclosedfolder2_ [l=hr] {otvori pod-odjeljak: }
_texticonopenfolder_ [l=hr] {zatvori mapu}
_texticonopenfolder2_ [l=hr] {zatvori pod-odjeljak: }
_texticonsmalltext_ [l=hr] {Pogledaj tekst ovog odjeljka}
_texticonsmalltext2_ [l=hr] {pogledaj tekst: }
_texticonpointer_ [l=hr] {trenutni odjeljak}
_texticondetach_ [l=hr] {Otvori ovu stranicu u novom prozoru}
_texticonhighlight_ [l=hr] {Označi tražene pojmove}
_texticonnohighlight_ [l=hr] {Nemoj označavati tražene pojmove}
_texticoncontracttoc_ [l=hr] {Sažmi prikaz sadržaja}
_texticonexpandtoc_ [l=hr] {Prikaži sadržaj}
_texticonexpandtext_ [l=hr] {Prikaži cijeli tekst}
_texticoncontracttext_ [l=hr] {Prikaži tekst samo trenutno označenog odjeljka}
_texticonwarning_ [l=hr] {<b>Upozorenje: </b>}
_texticoncont_ [l=hr] {nastavak?}

_textltwarning_ [l=hr] {
<p><center>
<table cellspacing=0 cellpadding=0 width=_pagewidth_>
<tr valign=top><td>_iconwarning_Dodavanje novog teksta će generirati veliku količinu podataka 
za prikaz u Vašem pregledniku _imagecont_
</td></tr></table></center>
}

_textgoto_ [l=hr] {idi na stranicu}
_textintro_ [l=hr] { <i>(uvodni tekst)</i>}


#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "naslovi a-z" ## green_title ## h_title ##
_httpiconhtitle_ [l=hr] {_httpimg_/hr/h_title.gif}
_widthhtitle_ [l=hr] {200}
_heighthtitle_ [l=hr] {57}

## "autori a-z" ## green_title ## h_auth ##
_httpiconhauth_ [l=hr] {_httpimg_/hr/h\_auth.gif}
_widthhauth_ [l=hr] {200}
_heighthauth_ [l=hr] {57}

## "područja" ## green_title ## h_subj ##
_httpiconhsubj_ [l=hr] {_httpimg_/hr/h\_subj.gif}
_widthhsubj_ [l=hr] {200}
_heighthsubj_ [l=hr] {57}

## "nizovi" ## green_title ## h_ser ##
_httpiconhser_ [l=hr] {_httpimg_/hr/h\_ser.gif}
_widthhser_ [l=hr] {200}
_heighthser_ [l=hr] {57}

## "datumi" ## green_title ## h_date ##
_httpiconhdate_ [l=hr] {_httpimg_/hr/h\_date.gif}
_widthhdate_ [l=hr] {200}
_heighthdate_ [l=hr] {57}

## "kako da" ## green_title ## h_how ##
_httpiconhhow_ [l=hr] {_httpimg_/hr/h\_how.gif}
_widthhhow_ [l=hr] {200}
_heighthhow_ [l=hr] {57}

## "teme" ## green_title ## h_topic ##
_httpiconhtopic_ [l=hr] {_httpimg_/hr/h\_topic.gif}
_widthhtopic_ [l=hr] {200}
_heighthtopic_ [l=hr] {57}

## "organizacije" ## green_title ## h_org ##
_httpiconhorg_ [l=hr] {_httpimg_/hr/h\_org.gif}
_widthhorg_ [l=hr] {250}
_heighthorg_ [l=hr] {57}

## "pregled" ## green_title ## h_brwse ##      ???
_httpiconhbrwse_ [l=hr] {_httpimg_/hr/h\_brwse.gif}
_widthhbrwse_ [l=hr] {200}
_heighthbrwse_ [l=hr] {57}

## "metapregled" ## green_title ## h_brwse ##    ???
_httpiconhbrows_ [l=hr] {_httpimg_/hr/h\_brwse.gif}
_widthhbrows_ [l=hr] {200}
_heighthbrows_ [l=hr] {57}

## "ljudi" ## green_title ## h_people ##
_httpiconhpeople_ [l=hr] {_httpimg_/hr/h\_people.gif}
_widthhpeople_ [l=hr] {200}
_heighthpeople_ [l=hr] {57}

## "jezici" ## green_title ## h_lang ##
_httpiconhlanguage_ [l=hr] {_httpimg_/hr/h\_lang.gif}
_widthhlanguage_ [l=hr] {200}
_heighthlanguage_ [l=hr] {57}

## "akronimi" ## green_title ## h_acro ##
_httpiconhacronym_ [l=hr] {_httpimg_/hr/h\_acro.gif}
_widthhacronym_ [l=hr] {200}
_heighthacronym_ [l=hr] {57}

## "fraze" ## green_title ## h_phrse ##
_httpiconhphrse_ [l=hr] {_httpimg_/hr/h\_phrse.gif}
_widthhphrse_ [l=hr] {200}
_heighthphrse_ [l=hr] {57}

## "umjetnici" ## green_title ## h_artist ##
_httpiconhartist_ [l=hr] {_httpimg_/hr/h\_artist.gif}
_widthhartist_ [l=hr] {200}
_heighthartist_ [l=hr] {57}

## "datoteke" ## green_title ## h_src ##
_httpiconhsrc_ [l=hr] {_httpimg_/hr/h_src.gif}
_widthhsrc_ [l=hr] {200}
_heighthsrc_ [l=hr] {57}

## "ključne riječi" ## green_title ## h_kw ##
_httpiconhkw_ [l=hr] {_httpimg_/hr/h_kw.gif}
_widthhkw_ [l=hr] {200}
_heighthkw_ [l=hr] {57}

## "NASTAVAK?" ## top_nav_button ## cont ##
_httpiconcontoff_ [l=hr] {_httpimg_/hr/contof.gif}
_httpiconconton_ [l=hr] {_httpimg_/hr/conton.gif}

## "PRIKAŽI TEKST" ## document_button ## eallt ## 
_httpiconealltof_ [l=hr] {_httpimg_/hr/ealltof.gif}
_httpiconeallton_ [l=hr] {_httpimg_/hr/eallton.gif}

## "SAŽMI SADRŽAJ" ## document_button ## econc ##
_httpiconeconcof_ [l=hr] {_httpimg_/hr/econcof.gif}
_httpiconeconcon_ [l=hr] {_httpimg_/hr/econcon.gif}

## "NOVI PROZOR" ## document_button ## edtch ##
_httpiconedtchof_ [l=hr] {_httpimg_/hr/edtchof.gif}
_httpiconedtchon_ [l=hr] {_httpimg_/hr/edtchon.gif}

## "PRIKAŽI SADRŽAJ" ## document_button ## eexpc ##
_httpiconeexpcof_ [l=hr] {_httpimg_/hr/eexpcof.gif}
_httpiconeexpcon_ [l=hr] {_httpimg_/hr/eexpcon.gif}

## "SAŽMI TEKST" ## document_button ## etsec ##
_httpiconetsecof_ [l=hr] {_httpimg_/hr/etsecof.gif}
_httpiconetsecon_ [l=hr] {_httpimg_/hr/etsecon.gif}

## "OZNAČAVANJE" ## document_button ## ehl ##
_httpiconehlof_ [l=hr] {_httpimg_/hr/ehlof.gif}
_httpiconehlon_ [l=hr] {_httpimg_/hr/ehlon.gif}

## "BEZ OZNAČAVANJA" ## document_button ## enhl ##
_httpiconenhlof_ [l=hr] {_httpimg_/hr/enhlof.gif}
_httpiconenhlon_ [l=hr] {_httpimg_/hr/enhlon.gif}


######################################################################
# 'search' page
package query
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

# this if statement produces the text 'results n1 - nn for query: querystring' or 
# 'No matches for query: querystring', depending on whether or not there were
# any matches
_textquerytitle_ [l=hr] {_If_(_thislast_,results _thisfirst_ - _thislast_ za upit: _cgiargq_, Ne zadovoljava upit: _cgiargq_)}
_textnoquerytitle_ [l=hr] {Pretraživanje}

_texticonthispage_ [l=hr] {traži}
_textsome_ [l=hr] {_If_(_cgiargb_,nizane,neke)}
_textall_ [l=hr] {_If_(_cgiargb_,booleove,sve)}
_textformsome_ [l=hr] {_If_(_cgiargb_,nizane,neke)}
_textformall_ [l=hr] {_If_(_cgiargb_,prirodne,sve)}
_texticonqueryresultsbar_ [l=hr] {}
_texticonsearchhistorybar_ [l=hr] {Popis prethodnih pretraživanja}

#alt text for query buttons
_textusequery_ [l=hr] {koristi ovaj upit}
_textfreqmsg1_ [l=hr] {Broj riječi: }

_textmorethan_ [l=hr] {Više od }
_textapprox_ [l=hr] {O }
_textnodocs_ [l=hr] {Nijedan dokument ne zadovoljava upit.}
_text1doc_ [l=hr] {1 dokument zadovoljava upit.}
_textlotsdocs_ [l=hr] {dokumenta zadovoljavaju upit.}
_textmatches_ [l=hr] {Zadovoljava }
_textbeginsearch_ [l=hr] {Početak pretraživanja}
_textrunquery_ [l=hr] {Izvrši upit}
_textclearform_ [l=hr] {Novi upit}

#these go together in form search:
#"Word or phrase  (fold, stem)  ... in field"
_textwordphrase_ [l=hr] {Riječ ili frazu}
_textinfield_ [l=hr] {... u polju}

_textadvquery_ [l=hr] {Ili unesi upit izravno:}
_textallfields_ [l=hr] {Sva polja}
_textand_ [l=hr] {i}
_textor_ [l=hr] {ili}
_textandnot_ [l=hr] {i ne}

# _hselection_, _jselection_, _nselection_ and _gselection_ are set from 
# within the server some or all of them may remain unset


_textsimplesearch_ [l=hr] {Traži prema _If_(_hselection_, _hselection_) _If_(_jselection_, _textjselect_) _If_(_gselection_, at _gselection_ level) _If_(_nselection_, in _nselection_ language)
koji sadrži _querytypeselection_ riječi}

_textadvancedsearch_ [l=hr] {Traži _If_(_hselection_, _hselection_, _defaultindextext_) _If_(_jselection_,_textjselect_) _If_(_gselection_, at _gselection_ level)_If_(_nselection_, in _nselection_ language) 
koristeći _querytypeselection_ upite}

_textsimplesearchmgpp_ [l=hr] {Traži prema _fqfselection_  _If_(_jselection_, of _jselection_) _If_(_gselection_, at _gselection_ level) _If_(_nselection_, in _nselection_ language)
koji sadrži _querytypeselection_ riječi}

_textadvancedsearchmgpp_ [l=hr] {Traži _fqfselection_ _If_(_jselection_,of _jselection_) _If_(_gselection_, at _gselection_ level)_If_(_nselection_, in _nselection_ language) 
koristeći _querytypeselection_ upite}

_textformsimplesearch_ [l=hr] {Traži prema _If_(_jselection_, _jselection_) _If_(_gselection_, at _gselection_ level) _If_(_nselection_, in _nselection_ language)
koji sadrži _formquerytypeselection_ of}

_textformadvancedsearch_ [l=hr] {Traži _If_(_jselection_,_jselection_) _If_(_gselection_, at _gselection_ level)_If_(_nselection_, in _nselection_ language) 
i prikaži rezultate po _formquerytypeselection_ redu}


_textjselect_ [l=hr] {_If_(_hselection_, of) _jselection_}

_textstemon_ [l=hr] { (ne uzima u obzir krajeve riječi)}

_textsearchhistory_ [l=hr] {Popis prethodnih pretraživanja}

#text macros for search history
_textnohistory_ [l=hr] {Popis prethodnih pretraživanja nije dostupan}
_texthresult_ [l=hr] {rezultat}
_texthresults_ [l=hr] {rezultata}
_texthallwords_ [l=hr] {sve riječi}
_texthsomewords_ [l=hr] {neke riječi}
_texthboolean_ [l=hr] {booleov}
_texthranked_ [l=hr] {nizan}
_texthcaseon_ [l=hr] {prepoznaje velika slova}
_texthcaseoff_ [l=hr] {ne prepoznaje velika slova}
_texthstemon_ [l=hr] {nepotpuna riječ}
_texthstemoff_ [l=hr] {potpuna riječ}

#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "traži" ## green_title ## h_search ##
_httpiconhsearch_ [l=hr] {_httpimg_/hr/h_search.gif}
_widthhsearch_ [l=hr] {200}
_heighthsearch_ [l=hr] {57}

## "rezultati" ## green_bar_left_aligned ## qryresb ##
_httpiconqryresb_ [l=hr] {_httpimg_/hr/qryresb.gif}
_widthqryresb_ [l=hr] {_pagewidth_}
_heightqryresb_ [l=hr] {17}

## "popis prethodnih pretraživanja" ## green_bar_left_aligned ## schhistb ##
_httpiconsrchhistb_ [l=hr] {_httpimg_/hr/schhistb.gif}
_widthsrchhistb_ [l=hr] {_pagewidth_}
_heightsrchhistb_ [l=hr] {17}

## "prikaz" ## hand_made ##
_httpicondisplay_ [l=hr] {_httpimg_/display.gif}
_widthdisplay_ [l=hr] {60}
_heightdisplay_ [l=hr] {20}


######################################################################
# 'preferences' page
package preferences
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textprefschanged_ [l=hr] {
Postavke su podešene kako slijedi. Ne koristite gumb za povratak u pregledniku
kako bi postavljene vrijednosti i sačuvali! Umjesto toga, kliknite na 
jednu od gornjih poveznica za nastavak. }

_textsetprefs_ [l=hr] {podesi postavke}
_textsearchprefs_ [l=hr] {Postavke pretraživanja}
_textcollectionprefs_ [l=hr] {Postavke zbirke}
_textpresentationprefs_ [l=hr] {Postavke prezentacije ili prikaza}
_textpreferences_ [l=hr] {Postavke}
_textcasediffs_ [l=hr] {Razlika između malih i velikih slova:}
_textignorecase_ [l=hr] { ne uzimaj u obzir razliku između malih i velikih slova}
_textmatchcase_ [l=hr] { razlika između malih i velikih slova mora biti uzeta u obzir:}
_textwordends_ [l=hr] {Krajevi riječi:}
_textstem_ [l=hr] { ne uzimaj u obzir krajeve riječi}
_textnostem_ [l=hr] { cijela riječ mora biti uzeta u obzir}
_textprefop_ [l=hr] {Vrati do _maxdocoption_ zadovoljavajućih odgovora na upit i prikaži ih _hitsperpageoption_ po stranici.}
_textextlink_ [l=hr] {Pristup vanjskim mrežnim stranicama:}
_textintlink_ [l=hr] {Izvorni dokumenti pronađeni u:}
_textlanguage_ [l=hr] {Jezik sučelja:}
_textencoding_ [l=hr] {Kodiranje:}
_textformat_ [l=hr] {Format sučelja:}
_textall_ [l=hr] {sve}
_textquerymode_ [l=hr] {Načini pretraživanja:}
_textsimplemode_ [l=hr] { jednostavno pretraživanje}
_textadvancedmode_ [l=hr] { napredno pretraživanje (dopuštena uporaba Booleovih operatora !, &, |, i zagrada)}
_textlinkinterm_ [l=hr] {kroz posredničku stranicu}
_textlinkdirect_ [l=hr] {idi izravno tamo}
_textdigitlib_ [l=hr] {digitalna knjižnica}
_textweb_ [l=hr] {web}
_textgraphical_ [l=hr] {Grafičko}
_texttextual_ [l=hr] {Tekstualno}
_textcollectionoption_ [l=hr] {<p>
Subcollections to include:
<br>}
_textrelateddocdisplay_ [l=hr] {prikaži srodne dokumente}
_textsearchhistory_ [l=hr] {Popis prethodnih pretraživanja:}
_texthistorydisplay_ [l=hr] {prikaži _historynumrecords_ popis prethodnih pretraživanja}
_textnohistorydisplay_ [l=hr] {nemoj prikazati popis prethodnih pretraživanja}

_texttypesearch_ [l=hr] {Vrsta pretraživanja:}
_texttextsearch_ [l=hr] {pretraživanje teksta}
_textformsearch_ [l=hr] {obrazac pretraživanja}
_textqueryboxsize_ [l=hr] {Veličina okvira za upit:}
_textregbox_ [l=hr] { obični okvir za upit}
_textbigbox_ [l=hr] { veliki okvir za upit}
_textformtype_ [l=hr] {Tip obrasca:}
_textsimple_ [l=hr] { jednostavno}
_textadvanced_ [l=hr] { napredno}

# used in "with 4 fields" in the form search box
_textwith_ [l=hr] {sa}
_textfields_ [l=hr] {polja}


#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "POSTAVKE" ## green_title ## h_pref ##
_httpiconhpref_ [l=hr] {_httpimg_/hr/h_pref.gif}
_widthhpref_ [l=hr] {200}
_heighthpref_ [l=hr] {57}


######################################################################
# 'help' page -- this is lower priority for translating than the
# rest of this file
package help
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textHelp_ [l=hr] {Pomoć}
_textSearchshort_ [l=hr] {pretraživanjem prema pojedinim riječima}
_textSeriesshort_ [l=hr] {pristupom traženoj građi putem naziva nizova}
_textDateshort_ [l=hr] {pristupom traženoj građi odabirom vremena njenog nastanka}
_textSubjectshort_ [l=hr] {pristupom traženoj građi preko područja po kojima je razvrstana}
_textTitleshort_ [l=hr] {pristupom traženoj građi putem naslova}
_textBrowseshort_ [l=hr] {pregledavanjem digitalne građe}
_textCreatorshort_ [l=hr] {pristupom traženoj građi putem imena autora}
_textOrganizationshort_ [l=hr] {pristupom traženoj građi putem naziva organizacija}
_textHowtoshort_ [l=hr] {pristupom traženoj građi putem "Kako da" kategorije}
_textTopicshort_ [l=hr] {pristupom traženoj građi putem naziva tema}
_textPeopleshort_ [l=hr] {pristupom traženoj građi putem imena osoba}
_textLanguageshort_ [l=hr] {pristupom traženoj građi putem odabira jezika}
_textAcronymshort_ [l=hr] {pristupom traženoj građi putem akronima}
_textPhraseshort_ [l=hr] {pregledavanjem fraza koje se javljaju u digitalnoj građi}
_textArtistshort_ [l=hr] {pristupom traženoj građi putem imena umjetnika}
_textSourceshort_ [l=hr] {pristupom traženoj građi putem naziva datoteka}
_textKeywordshort_ [l=hr] {pristupom traženoj građi putem ključnih riječi}
_textdefaultshorttext_ [l=hr] {klasifikacijom koja nije definirana}

_textSearchlong_ [l=hr] { <p>Možete <i>pretraživati prema pojedinim riječima</i> koje se pojavljuju u tekstu
 na stranici "traži". To je prva stranica koja se prikazuje kod otvaranja zbirke 
, a kojoj se može pristupiti sa drugih stranica zbirke pritiskom na gumb 
 <i>traži</i>.  }

_textTitlelong_ [l=hr] { <p>Možete <i>pristupiti građi putem naslova dokumenta i odjeljaka unutar dokumenta</i> pritiskom na gumb
 <i>naslovi a-z</i>.  Prikazuje se popis naslova prema abecednom redu.  }

_textOrganizationlong_ [l=hr] { <p>Možete <i>pristupiti građi putem naziva organizacija
</i> pritiskom na gumb <i>organizacije</i>.  Prikazuje se popis naziva organizacija. }

_textHowtolong_ [l=hr] { <p>Možete <i>pristupiti građi putem "Kako da" kategorije</i>
pritiskom na gumb <i>kako da</i>.  Prikazuje se popis "Kako da" fraza.  }

_textCreatorlong_ [l=hr] { <p>Možete <i>pristupiti građi putem imena autora</i> pritiskom na gumb
 <i>autori a-z</i>.  Prikazuje se popis knjiga sortiran prema imenu autora.  }

_textTopiclong_ [l=hr] { <p>Možete <i>pristupiti građi putem naziva tema</i> pritiskom na gumb
 <i>teme</i>.  Prikazuje se popis zastupljenih tema.  }

_textSubjectlong_ [l=hr] { <p>Možete <i>pristupiti građi preko područja u kojima je razsvrstana</i> pritiskom na gumb
 <i>područja</i>.  Prikazuje se popis područja po kojima je građa razvrstana, reprezentirana tzv. policama za knjige.  }

_textSerieslong_ [l=hr] { <p>Možete <i>pristupiti građi putem naziva nizova</i> pritiskom na gumb
 <i>nizovi</i>.  Prikazuje se popis nizova koji su trenutno zastupljeni u zbirci.  }

_textDatelong_ [l=hr] { <p>Možete <i>pristupiti građi odabirom datuma odnosno vremena njenog nastanka </i> pritiskom na gumb
 <i>datumi</i>.  Prikazuje se popis svih izdanja sortiran kronološki.  }

_textBrowselong_ [l=hr] { <p>Možete <i>pregledavati građu</i> pritiskom na gumb
<i>pregled</i>.  }

_textPeoplelong_ [l=hr] { <p>Možete <i>pristupiti građi putem imena osoba</i> pritiskom na gumb
 <i>ljudi a-z</i>.  Prikazuje se popis osoba sortiran prema njihovim prezimenima.  }

_textLanguagelong_ [l=hr] { <p>Možete <i>pristupiti građi putem odabira jezika</i> pritiskom na gumb
 <i>jezici</i>.  Prikazuje se popis jezika kojima je zbirka zastupljena.  }

_textAcronymlong_ [l=hr] { <p>Možete <i>pristupiti građi putem akronima koji se u njoj javljaju</i> pritiskom na gumb
 <i>akronimi</i>.  Prikazuje se popis akronima i mjesta gdje se pojavljuju.  }

_textPhraselong_ [l=hr] { <p>Možete <i>pregledavati fraze koje se javljaju u građi</i> pritiskom na gumb
 <i>fraze</i>.  Prikazuje se popis fraza zastupljenih u zbirci.  }

_textArtistlong_ [l=hr] { <p>Možete <i>pristupiti građi putem imena umjetnika</i> pritiskom na gumb
 <i>umjetnici</i>.  Prikazuje se popis imena umjetnika.  }

_textSourcelong_ [l=hr] { <p>Možete <i>pristupiti traženoj građi putem naziva datoteka</i> pritiskom na gumb
 <i>datoteke</i>.  Prikazuje se popis izvornih datoteka uključenih u zbirku prema abecednom redu.  }

_textKeywordlong_ [l=hr] { <p>Možete <i>pristupiti građi putem ključnih riječi</i> pritiskom na gumb <i>ključne riječi</i>. 
Prikazuje se lista ključnih riječi u obliku kazala. }

_textdefaultlongtext_ [l=hr] { <p>Kliknite na gumb <i>nepoznato</i> da pregledavate
 građu (sortiranu prema nepoznatom polju).  }

_texthelptopics_ [l=hr] {
<h2 align=left>Teme</h2>
<ul>
  <li><a href="\#finding-information">_textsimplehelpheading_</a>
  _topicreadingdocs_
  <li><a href="\#searching">Kako pretraživati prema pojedinim riječima</a>
<ul>
  <li><a href="\#query-terms">Traženi pojmovi</a>
  <li><a href="\#query-type">Vrste upita</a>
  <li><a href="\#scope-of-queries">Opseg upita</a>
</ul>
  <li><a href="\#preferences">_textchangeprefs_</a>
<ul>
  <li><a href="\#col-prefs">Postavke zbirke</a>
  <li><a href="\#lang-prefs">Jezične postavke</a>
  <li><a href="\#pres-prefs">Postavke prikaza</a>
  <li><a href="\#search-prefs">Postavke pretraživanja</a>
</ul>
</ul>
}

# there are 4 versions of this section of the help text.
# which version is used is currently set within the server
# (it should probably use the macro language e.g. [type=book])
# 1 = html (like fao collections) -- section is empty
# 2 = book (like hdl collection) -- macros beginning with book
# 3 = bibliographic (like csbib) -- macros beginning with bib
# 4 = standard (like gberg) -- the default

_topicreadingdocs_ [l=hr] {<li><a href="\#reading-docs">_textreadingdocs_</a>}

_textreadingdocs_ [l=hr] {Kako čitati dokumente}
_booktextreadingdocs_ [l=hr] {Kako čitati knjige}
_bibtextreadingdocs_ [l=hr] {Više informacija o bibliografskoj jedinici}

_texthelpreadingdocs_ [l=hr] {
<p>_iconblankbar_
<a name=reading-docs>
<h2>_textreadingdocs_</h2>

<p>Kada otvorite zasebni dokument njegov naslov i autor se pojavljuju u lijevom gornjem kutu stranice 
(Ponekad to moze biti i slika, naprimjer dobivena skeniranjem korica knjige, koja reprezentira dokument).   
Pored njih se nalazi podatak o stranici na kojoj se trenutno nalazite, te se nudi mogućnost odabira sljedeće stranice ili povratak na prethodnu. 
Ove mogućnosti su opcionalne i moraju se posebno definirati u konfiguracijskim postavkama.

<p>Ispod se prikazuje tekst odjeljka na kojem se trenutno nalazite. Na dnu svake stranice moguće je postaviti vodiče u obliku strelica 
koji vode na narednu ili prethodnu stranicu odjeljka.

<p>Ispod naslova i autora odnosno zasebne slike koja predstavlja dokument nalaze se tri gumba. Klikom na <i>prikaži 
tekst</i> prikazat će se cijeli tekst dokumenta. 
Ako je riječ o velikom dokumentu možda će trebati vremena da se on učita u preglednik. 
Klikom na <i>novi prozor</i> dokument će se otvoriti u novom prozoru preglednika (Ovo je korisno ako želite uporediti dokumente ili ih čitati istovremeno.)  
Konačno, kod pretraživanja traženi pojam je u tekstu označen žutom bojom.
Klikom na <i>bez oznacavanja</i> otklanjate ovu mogućnost.
<p>
<table cellspacing="0" cellpadding="2" border="0">
<tr><td colspan=2><img src="_httpiconmore_" border="0"></td><td>Klikni na strelicu za prikaz narednog odjeljka...</td></tr>
<tr><td colspan=2><img src="_httpiconless_" border="0"></td><td>... ili prikaz prethodnog odjeljka</td></tr>
<tr><td><img src="_document:httpiconealltof_" border="0"></td><td><img 
src="_document:httpiconetsecof_" border="0"></td><td>Prikaži cijeli tekst, ili ne</td></tr>
<tr><td colspan=2><img src="_document:httpiconedtchof_" border="0"></td><td>Otvori stranicu u novom prozoru</td></tr>
<tr><td><img src="_document:httpiconehlof_" border="0"></td><td><img
src="_document:httpiconenhlof_" border="0"></td><td>Označi tražene pojmove, ili ne</td></tr>
</table>

}

_booktexthelpreadingdocs_ [l=hr] {
<p>_iconblankbar_
<a name=reading-docs>
<h2>_textreadingdocs_</h2>

<p>Nalazite se na naslovnoj stranici pojedine knjige ukoliko se 
s lijeve strane na vrhu stranice pojavi fotografija s naslovnicom knjige. 
Pored fotografije smješten je sadržaj sa strelicom koja označava mjesto gdje se trenutno nalazite. 
Sadržaj se može prikazati u cijelosti: kliknite na mapu kako biste ju otvorili ili zatvorili.

<p>U donjem dijelu se nalazi tekst odjeljka u kojem se trenutno nalazite. Kada dođete do kraja odjeljka na dnu stranice se nalaze
strelice koje vas vode naprijed do narednog ili nazad do prethodnog odjeljka.

<p>Ispod fotografije se nalaze četiri gumba.  Klikom na <i>prikaži 
tekst</i> prikazat će se cijeli tekst odjeljka u kojem se trenutno nalazite ili knjige.  Ako je knjiga 
velika, ovo će zahtjevati mnogo vremena i bit će potrebno mnogo memorije! Klikom na
<i>prikaži sadržaj</i> prikazat će se cijeli sadržaj knjige te će te moći vidjeti 
naslove svih poglavlja i pododjeljaka.  Klikom na <i>novi prozor</i> knjiga će se otvoriti u novom prozoru preglednika. 
(Ovo je korisno ukoliko želite usporediti knjige ili istovremeno čitati dvije knjige.) Konačno, 
kod pretraživanja je traženi pojam u tekstu označen žutom bojom.
Klikom na <i>bez oznacavanja</i> otklanjate ovu mogućnost.

<p>
<table cellspacing="0" cellpadding="2" border="0">
<tr><td colspan=2><img src="_httpiconbshelf_" border="0"></td><td>Otvori ovu policu za knjige</td></tr>
<tr><td><img src="_httpiconopenbook_" border="0"></td><td><img 
src="_httpiconbook_" border="0"></td><td>Otvori/zatvori ovu knjigu</td></tr>
<tr><td colspan=2><img src="_httpiconitext_" border="0"></td><td>Pogledaj tekst ovog odjeljka</td></tr>
<tr><td><img src="_document:httpiconealltof_" border="0"></td><td><img 
src="_document:httpiconetsecof_" border="0"></td><td>Prikaži cijeli tekst, ili ne</td></tr>
<tr><td><img src="_document:httpiconeexpcof_" border="0"></td><td><img
src="_document:httpiconeconcof_" border="0"></td><td>Prikaži sadržaj, ili ne</td></tr>
<tr><td colspan=2><img src="_document:httpiconedtchof_" border="0"></td><td>Otvori stranicu u novom prozoru</td></tr>
<tr><td><img src="_document:httpiconehlof_" border="0"></td><td><img
src="_document:httpiconenhlof_" border="0"></td><td>Označi tražene pojmove, ili ne</td></tr>
<tr><td colspan=2><img src="_httpiconmore_" border="0"></td><td>Klikni na strelicu za prikaz narednog odjeljka...</td></tr>
<tr><td colspan=2><img src="_httpiconless_" border="0"></td><td>... ili prikaz prethodnog odjeljka</td></tr>
</table>
}

_bibtexthelpreadingdocs_ [l=hr] {
<p>_iconblankbar_
<a name=reading-docs>
<h2>_textreadingdocs_</h2>

<p>Neke bibliografske jedinice sadrže više informacija, poput sažetka. 
To možete ustanoviti ukoliko su na stranici odgovora na zadani upit 
jedinice prikazane putem _icontext_ ikone umjesto _iconblanktext_ ikone.  
<p>Klikom na _icontext_ ikonu dobiti će te više informacija o bibliografskoj jedinici. 

<p> Ispod bibliografske jedinice nalaze se dva gumba. Klikom na <i>novi prozor</i> bibliografska jedinica će se 
otvoriti u novom prozoru preglednika. (Ovo je korisno ukoliko želite usporediti dvije bibliogafske jedinice.)  Konačno, 
kod pretraživanja je traženi pojam u tekstu označen žutom bojom.
Klikom na <i>bez oznacavanja</i> otklanjate ovu mogućnost.
<p>
<table cellspacing="0" cellpadding="2" border="0">
<tr><td colspan=2><img src="_document:httpiconedtchof_" border="0"></td><td>Open this page in a new window</td></tr>
<tr><td><img src="_document:httpiconehlof_" border="0"></td><td><img
src="_document:httpiconenhlof_" border="0"></td><td>Highlight search terms, or not</td></tr>
</table>
}

_texthelpsearching_ [l=hr] {
<h2>Kako pretraživati prema pojedinim riječima</h2>
<p>
  Na stranici za pretraživanje, možete oblikovati upit na osnovu ovih jednostavnih koraka:<p>
  
  <ol><li>Pobliže označiti traženi pojam
      <li>Odrediti hoće li se pretraživanje obaviti prema svim ili samo nekim riječima zadanim u prethodnom koraku
      <li>Upisati riječi koje želite pronaći
      <li>Kliknuti na gumb <i>Početak pretraživanja</i>
  </ol>

<p>Na zaslonu će se potom prikazati najviše dvadeset naslova koji prema definiranim kriterijima 
zadovoljavaju upit. Pri dnu stranice se nalazi gumb koji omogućuje prikaz narednih dvadeset dokumenata itd.
Klikom na naslov dokumenta prikazuje se tekst dokumenta.

<p>Najviše 100 dokumenta koji prema odabranim kriterijima zadovoljavaju upit mogu biti vraćeni kao rezultati pretrage. 
Broj prikazanih rezultata možete također promijeniti na stranici <i>postavke</i> digitalne zbirke.<p>

<p>_iconblankbar_
<a name=query-terms>
<h3>Traženi pojmovi</h3>

<p>Što god da unesete u okvir za upit interpretira se kao niz riječi poznat pod nazivom "traženi pojmovi".
 Svaki traženi pojam se može sastojati od slova i brojki. Pojmovi su odvojeni razmakom. 
 Znakovi interpunkcije se zanemaruju te se tretiraju kao razmaci. 
 To znači da ne možete pretraživati putem riječi koje u sebi sadrže znakove interpunkcije.

<p>Naprimjer, upit<p>
    <ul><kbd>Agro-forestry in the Pacific Islands: Systems for Sustainability (1993)</kbd></ul>
      <p>biti će tretiran kao da ste upisali:<p>
      <ul><kbd>Agro forestry in the Pacific Islands  Systems for Sustainability  1993 </kbd></ul><p>

<p>_iconblankbar_
<a name=query-type>
<h3>Vrste upita</h3>

<p>Postoje dvije vrste upita.

<ul>
  <li>Upiti za <b>sve</b> riječi.  Ova vrsta upita pretražuje dokumente (ili
      poglavlja, ili naslove) koji sadrže sve riječi navedene u upitu.
      Dokumenti koji zadovoljavaju upit prikazuju se prema abecednom redu.<p>

  <li>Upiti za <b>neke</b> riječi.  Upiti ove vrste vraćaju popis pojmova koji se najvjerojatnije pojavljuju u dokumentima koji se pretražuju.
  Dokumenti se prikazuju prema stupnju zadovoljenja upita. 
  Kod određivanja stupnja zadovoljenja upita:
      <p><ul>
        <li> dokument sadrži više traženih pojmova, stupanj je viši;
        <li> rijetki pojmovi su mnogo važniji od onih koji se češče upotrebljavaju;
        <li> kraći dokumenti su bolje rješenje od duljih.
        </ul>
</ul>

<p>Možete koristiti onoliko traženih pojmova koliko želite - cijele rečenice,
ili čak cijele odlomke. Ako specificirate samo jedan pojam, dokumenti u odgovoru će biti prikazani u redosljedu prema
učestalosti pojavljivanja traženog pojma u njima.<p>

_texthelpscope_
}

_textchangeprefs_ [l=hr] {Izmjena Vaših postavki}

_texthelppreferences_ [l=hr] {<h2>_textchangeprefs_</h2>

<p>Ako kliknete na gumb <i>postavke</i> na vrhu svake stranice, moći će te  
mijenjati neka svojstva prikaza zbirke u sučelju, te prema Vašim željama i potrebama utjecati na neke postavke pretraživanja.

<p>_iconblankbar_
<a name=col-prefs>
<h3 align=left>Postavke zbirki</h3>

Neke zbirke uključuju više pojedinačnih zbirki, koje se onda mogu pretraživati ili zasebno ili zajedno.
Možete odabrati koju pojedinačnu zbirku želite uključiti u Vaše pretraživanje na stranici Postavke.

<p>_iconblankbar_
<a name=lang-prefs>
<h3 align=left>Jezične postavke</h3>

Iako svaka zbirka ima određenu vrijednost jezika koji se upotrebljava za predstavljanje zbirke, 
možete odabrati i neki drugi jezik.
Isto tako, možete promjeniti i kodnu stranicu za zadovoljavajući prikaz znakova u pregledniku.
Sve zbirke dopuštaju odabir između standardnog grafičkog i tekstualnog sučelja.
Ovo je naročito pogodno za korisnike sa posebnim potrebama koji rabe veće ekrane ili 
sintetizatore govora kao krajnje izlaze.

<p>_iconblankbar_
<a name=pres-prefs>
<h3 align=left>Postavke prikaza</h3>

Ovisno o pojedinoj zbirci, postoji nekoliko načina uspostavljanja nadzora njenog prikaza.

<p>Zbirke mrežnih stranica dopuštaju neprikazivanje 
Greenstone navigacijskih gumba na vrhu stranice dokumenata koji zadovoljavaju upit. 
Drugim riječima, nakon završenog pretraživanja možete učitati mrežnu stranicu koja zadovoljava upit 
bez pojavljivanja bilo kakvog Greenstone zaglavlja na učitanoj stranici. 
Za naredno pretraživanje prisiljeni ste koristiti opciju preglednika 
za povratak na prethodnu stranicu (klikom na "back" gumb).  
Isto tako, ove su zbirke u mogućnosti spriječiti pojavljivanje Greenstone upozoravajuće poruke 
u slučaju klika na poveznicu koja vas vodi izvan zbirke digitalne knjižnice odnosno na sam Web. 
U nekim mrežnim zbirkama možete učiniti da poveznice sa stranica izlistanih rezultata 
vode ravno na pripadajuće URL-ove mrežnih stranica koje zadovoljavaju upit a ne na kopije tih 
dokumenata pohranjenih u digitalnoj zbirci. 

<p>_iconblankbar_
<a name=search-prefs>
<h3 align=left>Postavke pretraživanja</h3>
<p>
Dva para radio-gumba kontroliraju oblik teksta zadanog u upitu. Prvi par 
(nazvan "Razlika između malih i velikih slova") određuje da li je razlikovanje malih i velikih slova u 
postavljenom upitu važna. Drugi par ("Krajevi riječi") određuje hoće li krajevi riječi u postavljenom upitu
biti ignorirani ili ne. Isto tako, postoji mogućnost postavljanja upita u velikom okviru za upit što pruža
mogućnost oblikovanja upita putem cijelih odlomaka. To naročito pomaže kod pretraživanja velike količine 
teksta.

<p>Naprimjer, ako su odabrane postavke pretraživanja <i>ignoriraj razliku između malih i velikih slova</i> i
<i>ignoriraj krajeve riječi</i> upit<p>
    <ul><kbd>African building</kbd></ul>
      <p>bio bi tretiran isto kao i <p>
      <ul><kbd>africa builds</kbd></ul><p>
      jer se veliko slovo u "African", ovim odabranim postavkama pretraživanja, pretvara u malo slovo
      , dok se nastavci "n" i "ing" potpuno uklanjaju (naravno, kao i nastavak "s" u riječi "builds").

<p>Možete odabrati i mogućnost naprednog pretraživanja koja dopušta u upitu kombinaciju pojmova i Booleovih operatora AND (&),
OR (|) i NOT (!). Ovo pridonosi uspješnijem oblikovanju upita.
Isto tako, možete uključiti i Popis prethodnih pretraživanja što vam daje mogućnost 
laganog preoblikovanja prethodnih upita s ciljem dobivanja što točnijih odgovora. Konačno, možete kontrolirati i broj 
 vraćenih odgovora na postavljeni upit jednostavnim odabirom ponuđenih brojeva u padajućem izborniku.
}

_texttanumbrowseoptions_ [l=hr] {Postoji _numbrowseoptions_ načina kako pronaći traženu informaciju u zbirci:}

_textsimplehelpheading_ [l=hr] {Kako pronaći traženu informaciju u _collectionname_ }

_texthelpscope_ [l=hr] {
<p>_iconblankbar_
<a name=scope-of-queries>
<h3 align=left>Opseg upita</h3>

<p>
U većini zbirki možete odabrati pretraživanje prema različitim indeksima. Primjerice, možete pretraživati prema 
indeksu autora ili naslova. Isto tako, možete pretraživati prema indeksima odjeljka ili odlomka. Općenito govoreći, 
traženi dokument je moguće pronaći neovisno o tome koji se indeks koristi. 
<p>Ako su dokumenti knjige, otvoriti će se upravo na odgovarajućim mjestima.
}
